################################################ Timing Constraints ################################################

# Set the RX1 clock frequency to 250 MHz
create_clock -name rx_clk -period 4.0 [get_ports sample_clk_p]
set_clock_groups -name async_rx_clk -asynchronous -group [get_clocks rx_clk]

# Set a false path to the clock input buffer used for dynamic phase alignment.
set_false_path -through [get_pins XCVR/RX_CH.ADC/CLK_FORWARD[1].CLK_DDR/D]

################################################ Pinout Constraints ################################################

# Sample clock generated by the frequency synthesizer.
set_property PACKAGE_PIN G22 [get_ports sample_clk_p]

# RX1 pin assignments.
set_property PACKAGE_PIN N19 [get_ports {rx1_data_in_p[0]}]
set_property PACKAGE_PIN P19 [get_ports {rx1_data_in_p[1]}]
set_property PACKAGE_PIN M21 [get_ports {rx1_data_in_p[2]}]
set_property PACKAGE_PIN N21 [get_ports {rx1_data_in_p[3]}]
set_property PACKAGE_PIN M24 [get_ports {rx1_data_in_p[4]}]
set_property PACKAGE_PIN K25 [get_ports {rx1_data_in_p[5]}]
set_property PACKAGE_PIN M25 [get_ports {rx1_data_in_p[6]}]
set_property PACKAGE_PIN P23 [get_ports {rx1_data_in_p[7]}]
set_property PACKAGE_PIN E17 [get_ports rx1_ovr_in]

# RX2 pin assignments.
set_property PACKAGE_PIN T24 [get_ports {rx2_data_in_p[0]}]
set_property PACKAGE_PIN T22 [get_ports {rx2_data_in_p[1]}]
set_property PACKAGE_PIN T20 [get_ports {rx2_data_in_p[2]}]
set_property PACKAGE_PIN R26 [get_ports {rx2_data_in_p[3]}]
set_property PACKAGE_PIN R25 [get_ports {rx2_data_in_p[4]}]
set_property PACKAGE_PIN R22 [get_ports {rx2_data_in_p[5]}]
set_property PACKAGE_PIN R21 [get_ports {rx2_data_in_p[6]}]
set_property PACKAGE_PIN P24 [get_ports {rx2_data_in_p[7]}]
set_property PACKAGE_PIN F17 [get_ports rx2_ovr_in]

# RX1/RX2 clock forward pin assignment.
set_property PACKAGE_PIN N26 [get_ports rx1_clk_in_p]

# RX3 pin assignments.
set_property PACKAGE_PIN U22 [get_ports {rx3_data_in_p[0]}]
set_property PACKAGE_PIN U24 [get_ports {rx3_data_in_p[1]}]
set_property PACKAGE_PIN U26 [get_ports {rx3_data_in_p[2]}]
set_property PACKAGE_PIN V23 [get_ports {rx3_data_in_p[3]}]
set_property PACKAGE_PIN W25 [get_ports {rx3_data_in_p[4]}]
set_property PACKAGE_PIN W23 [get_ports {rx3_data_in_p[5]}]
set_property PACKAGE_PIN Y25 [get_ports {rx3_data_in_p[6]}]
set_property PACKAGE_PIN Y23 [get_ports {rx3_data_in_p[7]}]
set_property PACKAGE_PIN H18 [get_ports rx3_ovr_in]

# RX4 pin assignments.
set_property PACKAGE_PIN AF24 [get_ports {rx4_data_in_p[0]}]
set_property PACKAGE_PIN AE23 [get_ports {rx4_data_in_p[1]}]
set_property PACKAGE_PIN AD23 [get_ports {rx4_data_in_p[2]}]
set_property PACKAGE_PIN AD25 [get_ports {rx4_data_in_p[3]}]
set_property PACKAGE_PIN AD26 [get_ports {rx4_data_in_p[4]}]
set_property PACKAGE_PIN AC23 [get_ports {rx4_data_in_p[5]}]
set_property PACKAGE_PIN AB26 [get_ports {rx4_data_in_p[6]}]
set_property PACKAGE_PIN AA23 [get_ports {rx4_data_in_p[7]}]
set_property PACKAGE_PIN H17 [get_ports rx4_ovr_in]

# RX3/RX4 clock forward pin assignment.
set_property PACKAGE_PIN AA25 [get_ports rx3_clk_in_p]

################################################ IDELAY Constraints ################################################

set_property IODELAY_GROUP ADC_GROUP [get_cells -hier -filter {NAME =~ *ADC_IDELAY}]
set_property IODELAY_GROUP ADC_GROUP [get_cells -hier -filter {NAME =~ *DATA_IDELAY}]
set_property IODELAY_GROUP ADC_GROUP [get_cells -hier -filter {NAME =~ *OVR_IDELAY}]
set_property IODELAY_GROUP ADC_GROUP [get_cells -hier -filter {NAME =~ *CLK_IDELAY}]
